@@ -210,7 +210,7 @@ class ApiDoc:
                     return ParamsErrorResponse(message = f"只允许{','.join([str(i) for i in method])}请求", code = 40003)
 
                 for i in params:
-                    if i.get('name') in list(form.keys()) or i.get('require'):
+                    if i.get('name') in list(form.keys()) and i.get('require'):
                         if form.get(i.get('name')) == '' or form.get(i.get('name')) is None:
                             return ParamsErrorResponse(message = f"{i.get('name')}不能为空")
                     else:
